Ważniejsze przyciski

Ważniejsze przyciski | Spis treści

Poniżej znajduje się krótki opis każdego przycisku

| Pogrubienie tekstu.
| Pochylenie tekstu.
| Podkreślenie tekstu.
| Przekreślenie tekstu.
| Wyrównanie do lewej
| Wyśrodkowanie.
| Wyrównanie do prawej.
| Wyjustowanie.
| Lista nieuporządkowana/lista punktów.
| Lista uporządkowana/lista ponumerowana
| Wysunięcie/zmniejsz wcięcie.
| Wcięcie/zwiększ wcięcie.
| Cofnięcie ostatnio wykonanej czynności
| Ponowienie ostatnio wykonanej czynności
| Wstawienie nowego łącza, przeczytaj więcej o tej funkcji sekcji Wstaw łącze.
| Usunięcie łącz z zaznaczonej części/usunięcie wszystkich zaznaczonych łącz.
| Wstawienie nowego zakotwiczenia, przeczytaj więcej o tej funkcji w sekcji Wstaw zakotwiczenie.
| Wstawienie nowego zdjęcia, przeczytaj więcej o tej funkcji w sekcji Wstaw zdjęcie.
| Oczyszczenie kodu/usunięcie niechcianeg formatowania. Ta funkcja jest pomocna kiedy kopiujesz zawartość np. z worda.
| Pokazanie tego okna pomocy.
| Otwarcie edytora kodu HTML.
| Wstawienie nowej tabeli 2x2 w bieżącej pozycji.
| Wstawienie wiersza ponad aktualnie zaznaczonym.
| Wstawienie wiersz poniżej aktualnie zaznaczonego.
| Usunięcie wiersza.
| Wstawienie kolumny przed aktualnie zaznaczoną.
| Wstawienie kolumny za aktualnie zaznaczoną.
| Usunięcie kolumny.
| Wstawienie poziomej linii.
| Usunięcie formatowania z zaznaczonej części.
| Przekształcenie w indeks dolny.
| Przekształcenie w indeks górny.

Idź do: Spis treści | Góra